@@ -1,9 +1,11 @@
+import logging
+
 from .oauth1_auth import OAuth1
 from .oauth1_session import OAuth1Session
 from .oauth2_auth import OAuth2
 from .oauth2_session import OAuth2Session, TokenUpdated
 
-__version__ = '0.8.0'
+__version__ = '1.1.0'
 
 import requests
 if requests.__version__ < '2.0.0':
@@ -11,12 +13,4 @@ if requests.__version__ < '2.0.0':
            'requests-oauthlib expects, please upgrade to 2.0.0 or later.')
     raise Warning(msg % requests.__version__)
 
-import logging
-try:  # Python 2.7+
-    from logging import NullHandler
-except ImportError:
-   class NullHandler(logging.Handler):
-       def emit(self, record):
-           pass
-
-logging.getLogger('requests_oauthlib').addHandler(NullHandler())
+logging.getLogger('requests_oauthlib').addHandler(logging.NullHandler())
